phpgroupware-cvs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Phpgroupware-cvs] property inc/class.socategory.inc.php inc/class...


From: Sigurd Nes
Subject: [Phpgroupware-cvs] property inc/class.socategory.inc.php inc/class...
Date: Tue, 02 Jan 2007 14:43:04 +0000

CVSROOT:        /sources/phpgroupware
Module name:    property
Changes by:     Sigurd Nes <sigurdne>   07/01/02 14:43:04

Modified files:
        inc            : class.socategory.inc.php 
                         class.soinvoice.inc.php 
                         class.sopricebook.inc.php hook_admin.inc.php 
        setup          : default_records.inc.php setup.inc.php 
                         tables_current.inc.php tables_update.inc.php 

Log message:
        cleanup

CVSWeb URLs:
http://cvs.savannah.gnu.org/viewcvs/property/inc/class.socategory.inc.php?cvsroot=phpgroupware&r1=1.19&r2=1.20
http://cvs.savannah.gnu.org/viewcvs/property/inc/class.soinvoice.inc.php?cvsroot=phpgroupware&r1=1.29&r2=1.30
http://cvs.savannah.gnu.org/viewcvs/property/inc/class.sopricebook.inc.php?cvsroot=phpgroupware&r1=1.17&r2=1.18
http://cvs.savannah.gnu.org/viewcvs/property/inc/hook_admin.inc.php?cvsroot=phpgroupware&r1=1.26&r2=1.27
http://cvs.savannah.gnu.org/viewcvs/property/setup/default_records.inc.php?cvsroot=phpgroupware&r1=1.38&r2=1.39
http://cvs.savannah.gnu.org/viewcvs/property/setup/setup.inc.php?cvsroot=phpgroupware&r1=1.56&r2=1.57
http://cvs.savannah.gnu.org/viewcvs/property/setup/tables_current.inc.php?cvsroot=phpgroupware&r1=1.72&r2=1.73
http://cvs.savannah.gnu.org/viewcvs/property/setup/tables_update.inc.php?cvsroot=phpgroupware&r1=1.64&r2=1.65

Patches:
Index: inc/class.socategory.inc.php
===================================================================
RCS file: /sources/phpgroupware/property/inc/class.socategory.inc.php,v
retrieving revision 1.19
retrieving revision 1.20
diff -u -b -r1.19 -r1.20
--- inc/class.socategory.inc.php        27 Dec 2006 10:37:59 -0000      1.19
+++ inc/class.socategory.inc.php        2 Jan 2007 14:43:03 -0000       1.20
@@ -8,7 +8,7 @@
        * @internal Development of this application was funded by 
http://www.bergen.kommune.no/bbb_/ekstern/
        * @package property
        * @subpackage admin
-       * @version $Id: class.socategory.inc.php,v 1.19 2006/12/27 10:37:59 
sigurdne Exp $
+       * @version $Id: class.socategory.inc.php,v 1.20 2007/01/02 14:43:03 
sigurdne Exp $
        */
 
        /**
@@ -105,8 +105,20 @@
 
                        switch($type)
                        {
+                               case 'dim_b':
+                                       $table='fm_ecodimb';
+                                       break;
                                case 'dim_d':
-                                       $table='fm_dim_d';
+                                       $table='fm_ecodimd';
+                                       break;
+                               case 'tax':
+                                       $table='fm_ecomva';
+                                       break;
+                               case 'voucher_cat':
+                                       $table='fm_ecobilag_category';
+                                       break;
+                               case 'voucher_type':
+                                       $table='fm_ecoart';
                                        break;
                                case 'tender_chapter':
                                        $table='fm_chapter';

Index: inc/class.soinvoice.inc.php
===================================================================
RCS file: /sources/phpgroupware/property/inc/class.soinvoice.inc.php,v
retrieving revision 1.29
retrieving revision 1.30
diff -u -b -r1.29 -r1.30
--- inc/class.soinvoice.inc.php 27 Dec 2006 10:37:59 -0000      1.29
+++ inc/class.soinvoice.inc.php 2 Jan 2007 14:43:03 -0000       1.30
@@ -8,7 +8,7 @@
        * @internal Development of this application was funded by 
http://www.bergen.kommune.no/bbb_/ekstern/
        * @package property
        * @subpackage eco
-       * @version $Id: class.soinvoice.inc.php,v 1.29 2006/12/27 10:37:59 
sigurdne Exp $
+       * @version $Id: class.soinvoice.inc.php,v 1.30 2007/01/02 14:43:03 
sigurdne Exp $
        */
 
        /**
@@ -645,7 +645,7 @@
                                else
                                {
                                        $dimd=$values['dimd'][$n];
-                                       $GLOBALS['phpgw']->db->query("select 
count(*) from  fm_dim_d where id =$dimd");
+                                       $GLOBALS['phpgw']->db->query("select 
count(*) from fm_ecodimd where id ='$dimd'");
                                        $GLOBALS['phpgw']->db->next_record();
                                        if ($GLOBALS['phpgw']->db->f(0) == 0)
                                        {
@@ -841,7 +841,7 @@
                        {
                                $art_list[] = Array(
                                        'id'        => $this->db->f('id'),
-                                       'name'       => $this->db->f('name')
+                                       'name'       => $this->db->f('descr')
                                );
                        }
 
@@ -852,12 +852,12 @@
 
                function get_type_list()
                {
-                       $this->db->query("SELECT * FROM fm_ecobilagtype order 
by id asc ");
+                       $this->db->query("SELECT * FROM fm_ecobilag_category 
order by id asc ");
                        while ($this->db->next_record())
                        {
                                $art_list[] = Array(
                                        'id'        => $this->db->f('id'),
-                                       'name'       => $this->db->f('name')
+                                       'name'       => $this->db->f('descr')
                                );
                        }
                        return $art_list;
@@ -871,7 +871,7 @@
                        {
                                $dimb_list[] = Array(
                                        'id'        => $this->db->f('id'),
-                                       'name'       => $this->db->f('name')
+                                       'name'       => $this->db->f('descr')
                                );
                        }
                        return $dimb_list;
@@ -885,7 +885,7 @@
                        {
                                $dimd_list[] = Array(
                                        'id'        => $this->db->f('id'),
-                                       'name'       => $this->db->f('name')
+                                       'name'       => $this->db->f('descr')
                                );
                        }
                        return $dimd_list;
@@ -899,7 +899,7 @@
                        {
                                $tax_code_list[] = Array(
                                        'id'        => $this->db->f('id'),
-                                       'name'       => $this->db->f('name')
+                                       'name'       => $this->db->f('descr')
                                );
                        }
                        return $tax_code_list;

Index: inc/class.sopricebook.inc.php
===================================================================
RCS file: /sources/phpgroupware/property/inc/class.sopricebook.inc.php,v
retrieving revision 1.17
retrieving revision 1.18
diff -u -b -r1.17 -r1.18
--- inc/class.sopricebook.inc.php       27 Dec 2006 10:37:59 -0000      1.17
+++ inc/class.sopricebook.inc.php       2 Jan 2007 14:43:03 -0000       1.18
@@ -8,7 +8,7 @@
        * @internal Development of this application was funded by 
http://www.bergen.kommune.no/bbb_/ekstern/
        * @package property
        * @subpackage agreement
-       * @version $Id: class.sopricebook.inc.php,v 1.17 2006/12/27 10:37:59 
sigurdne Exp $
+       * @version $Id: class.sopricebook.inc.php,v 1.18 2007/01/02 14:43:03 
sigurdne Exp $
        */
 
        /**
@@ -107,7 +107,7 @@
 
                function get_dim_d_list()
                {
-                       $this->db->query("SELECT * FROM fm_dim_d ORDER BY descr 
asc");
+                       $this->db->query("SELECT * FROM fm_ecodimd ORDER BY 
descr asc");
                        while ($this->db->next_record())
                        {
                                $dim_d_list[]=array

Index: inc/hook_admin.inc.php
===================================================================
RCS file: /sources/phpgroupware/property/inc/hook_admin.inc.php,v
retrieving revision 1.26
retrieving revision 1.27
diff -u -b -r1.26 -r1.27
--- inc/hook_admin.inc.php      5 Oct 2006 11:33:53 -0000       1.26
+++ inc/hook_admin.inc.php      2 Jan 2007 14:43:03 -0000       1.27
@@ -8,7 +8,7 @@
        * @internal Development of this application was funded by 
http://www.bergen.kommune.no/bbb_/ekstern/
        * @package property
        * @subpackage admin
-       * @version $Id: hook_admin.inc.php,v 1.26 2006/10/05 11:33:53 sigurdne 
Exp $
+       * @version $Id: hook_admin.inc.php,v 1.27 2007/01/02 14:43:03 sigurdne 
Exp $
        */
 
                {
@@ -60,7 +60,12 @@
                                'Branch'                                        
=> $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 
'property.uistandard_3.index', 'type' => 'branch') ),
                                'Accounting'                            => 
$GLOBALS['phpgw']->link('/index.php', array('menuaction' => 
'property.uib_account.index') ),
                                'Accounting Categories'         => 
$GLOBALS['phpgw']->link('/index.php', array('menuaction' => 
'property.uicategory.index', 'type' => 'b_account') ),
-                               'Accounting extra'                      => 
$GLOBALS['phpgw']->link('/index.php', array('menuaction' => 
'property.uicategory.index', 'type' => 'dim_d') ),
+                               'Accounting dim b'                      => 
$GLOBALS['phpgw']->link('/index.php', array('menuaction' => 
'property.uicategory.index', 'type' => 'dim_b') ),
+                               'Accounting dim d'                      => 
$GLOBALS['phpgw']->link('/index.php', array('menuaction' => 
'property.uicategory.index', 'type' => 'dim_d') ),
+                               'Accounting tax'                        => 
$GLOBALS['phpgw']->link('/index.php', array('menuaction' => 
'property.uicategory.index', 'type' => 'tax') ),
+                               'Accounting voucher category'   => 
$GLOBALS['phpgw']->link('/index.php', array('menuaction' => 
'property.uicategory.index', 'type' => 'voucher_cat') ),
+                               'Accounting voucher type'       => 
$GLOBALS['phpgw']->link('/index.php', array('menuaction' => 
'property.uicategory.index', 'type' => 'voucher_type') ),
+
                                'Import'                                        
=> $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 
'property.uiXport.import') ),
                                'Export'                                        
=> $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 
'property.uiXport.export') ),
                                'Admin Async servises'          => 
$GLOBALS['phpgw']->link('/index.php', array('menuaction' => 
'property.uialarm.index') ),

Index: setup/setup.inc.php
===================================================================
RCS file: /sources/phpgroupware/property/setup/setup.inc.php,v
retrieving revision 1.56
retrieving revision 1.57
diff -u -b -r1.56 -r1.57
--- setup/setup.inc.php 24 Nov 2006 14:37:05 -0000      1.56
+++ setup/setup.inc.php 2 Jan 2007 14:43:03 -0000       1.57
@@ -8,12 +8,12 @@
        * @internal Development of this application was funded by 
http://www.bergen.kommune.no/bbb_/ekstern/
        * @package property
        * @subpackage setup
-       * @version $Id: setup.inc.php,v 1.56 2006/11/24 14:37:05 sigurdne Exp $
+       * @version $Id: setup.inc.php,v 1.57 2007/01/02 14:43:03 sigurdne Exp $
        */
 
        $setup_info['property']['name']         = 'property';
        $setup_info['property']['title']        = 'Property';
-       $setup_info['property']['version']      = '0.9.17.535';
+       $setup_info['property']['version']      = '0.9.17.536';
        $setup_info['property']['app_order']    = 8;
        $setup_info['property']['enable']       = 1;
        $setup_info['property']['app_group']    = 'office';
@@ -103,7 +103,6 @@
                'fm_building_part',
                'fm_b_account',
                'fm_b_account_category',
-               'fm_dim_d',
                'fm_workorder',
                'fm_workorder_category',
                'fm_workorder_history',
@@ -142,7 +141,7 @@
                'fm_ecobilag',
                'fm_ecobilagkilde',
                'fm_ecobilagoverf',
-               'fm_ecobilagtype',
+               'fm_ecobilag_category',
                'fm_ecodimb',
                'fm_ecodimd',
                'fm_ecologg',

Index: setup/tables_current.inc.php
===================================================================
RCS file: /sources/phpgroupware/property/setup/tables_current.inc.php,v
retrieving revision 1.72
retrieving revision 1.73
diff -u -b -r1.72 -r1.73
--- setup/tables_current.inc.php        24 Nov 2006 10:11:49 -0000      1.72
+++ setup/tables_current.inc.php        2 Jan 2007 14:43:03 -0000       1.73
@@ -8,7 +8,7 @@
        * @internal Development of this application was funded by 
http://www.bergen.kommune.no/bbb_/ekstern/
        * @package property
        * @subpackage setup
-       * @version $Id: tables_current.inc.php,v 1.72 2006/11/24 10:11:49 
sigurdne Exp $
+       * @version $Id: tables_current.inc.php,v 1.73 2007/01/02 14:43:03 
sigurdne Exp $
        */
 
        $phpgw_baseline = array(
@@ -536,16 +536,6 @@
                        'ix' => array(),
                        'uc' => array()
                ),
-               'fm_dim_d' => array(
-                       'fd' => array(
-                               'id' => array('type' => 'int','precision' => 
'4','nullable' => False),
-                               'descr' => array('type' => 
'varchar','precision' => '25','nullable' => False)
-                       ),
-                       'pk' => array('id'),
-                       'fk' => array(),
-                       'ix' => array(),
-                       'uc' => array()
-               ),
                'fm_workorder' => array(
                        'fd' => array(
                                'id' => array('type' => 'int','precision' => 
'4','nullable' => False),
@@ -999,8 +989,7 @@
                'fm_ecoart' => array(
                        'fd' => array(
                                'id' => array('type' => 'int','precision' => 
'4','nullable' => False),
-                               'name' => array('type' => 'varchar','precision' 
=> '20','nullable' => False),
-                               'description' => array('type' => 
'text','nullable' => True)
+                               'descr' => array('type' => 
'varchar','precision' => '25','nullable' => False)
                        ),
                        'pk' => array('id'),
                        'ix' => array(),
@@ -1134,11 +1123,10 @@
                        'fk' => array(),
                        'uc' => array()
                ),
-               'fm_ecobilagtype' => array(
+               'fm_ecobilag_category' => array(
                        'fd' => array(
                                'id' => array('type' => 'int','precision' => 
'2','nullable' => False),
-                               'name' => array('type' => 'varchar','precision' 
=> '20','nullable' => False),
-                               'description' => array('type' => 
'text','nullable' => True)
+                               'descr' => array('type' => 
'varchar','precision' => '25','nullable' => False)
                        ),
                        'pk' => array('id'),
                        'ix' => array(),
@@ -1148,8 +1136,7 @@
                'fm_ecodimb' => array(
                        'fd' => array(
                                'id' => array('type' => 'int','precision' => 
'2','nullable' => False),
-                               'name' => array('type' => 'varchar','precision' 
=> '20','nullable' => False),
-                               'description' => array('type' => 
'text','nullable' => True)
+                               'descr' => array('type' => 
'varchar','precision' => '25','nullable' => False)
                        ),
                        'pk' => array('id'),
                        'ix' => array(),
@@ -1159,8 +1146,7 @@
                'fm_ecodimd' => array(
                        'fd' => array(
                                'id' => array('type' => 'varchar','precision' 
=> '5','nullable' => False),
-                               'name' => array('type' => 'varchar','precision' 
=> '20','nullable' => False),
-                               'description' => array('type' => 
'text','nullable' => True)
+                               'descr' => array('type' => 
'varchar','precision' => '25','nullable' => False)
                        ),
                        'pk' => array('id'),
                        'ix' => array(),
@@ -1169,9 +1155,8 @@
                ),
                'fm_ecomva' => array(
                        'fd' => array(
-                               'id' => array('type' => 'int','precision' => 
'2','nullable' => False),
-                               'name' => array('type' => 'varchar','precision' 
=> '20','nullable' => False),
-                               'description' => array('type' => 
'text','nullable' => True)
+                               'id' => array('type' => 'int','precision' => 
'4','nullable' => False),
+                               'descr' => array('type' => 
'varchar','precision' => '25','nullable' => False)
                        ),
                        'pk' => array('id'),
                        'ix' => array(),

Index: setup/tables_update.inc.php
===================================================================
RCS file: /sources/phpgroupware/property/setup/tables_update.inc.php,v
retrieving revision 1.64
retrieving revision 1.65
diff -u -b -r1.64 -r1.65
--- setup/tables_update.inc.php 24 Nov 2006 14:37:05 -0000      1.64
+++ setup/tables_update.inc.php 2 Jan 2007 14:43:03 -0000       1.65
@@ -8,7 +8,7 @@
        * @internal Development of this application was funded by 
http://www.bergen.kommune.no/bbb_/ekstern/
        * @package property
        * @subpackage setup
-       * @version $Id: tables_update.inc.php,v 1.64 2006/11/24 14:37:05 
sigurdne Exp $
+       * @version $Id: tables_update.inc.php,v 1.65 2007/01/02 14:43:03 
sigurdne Exp $
        */
 
        /**
@@ -1705,4 +1705,55 @@
        }
 
 
+       /**
+       * Update property version from 0.9.17.535 to 0.9.17.536
+       */
+
+       $test[] = '0.9.17.535';
+       function property_upgrade0_9_17_535()
+       {
+               $GLOBALS['phpgw_setup']->oProc->m_odb->transaction_begin();
+               $table_def = array(
+                       'fd' => array(
+                               'id' => array('type' => 'int','precision' => 
'4','nullable' => False),
+                               'descr' => array('type' => 
'varchar','precision' => '25','nullable' => False),
+                       ),
+                       'pk' => array('id'),
+                       'fk' => array(),
+                       'ix' => array(),
+                       'uc' => array()
+               );
+
+               $GLOBALS['phpgw_setup']->oProc->DropTable('fm_dim_d');
+
+               
$GLOBALS['phpgw_setup']->oProc->RenameColumn('fm_ecodimd','name','descr');
+               
$GLOBALS['phpgw_setup']->oProc->AlterColumn('fm_ecodimd','descr',array('type' 
=> 'varchar','precision' => '25','nullable' => False));
+               
$GLOBALS['phpgw_setup']->oProc->DropColumn('fm_ecodimd',$table_def,'description');
+
+               
$GLOBALS['phpgw_setup']->oProc->RenameColumn('fm_ecodimb','name','descr');
+               
$GLOBALS['phpgw_setup']->oProc->AlterColumn('fm_ecodimb','descr',array('type' 
=> 'varchar','precision' => '25','nullable' => False));
+               
$GLOBALS['phpgw_setup']->oProc->DropColumn('fm_ecodimb',$table_def,'description');
+
+               
$GLOBALS['phpgw_setup']->oProc->RenameColumn('fm_ecomva','name','descr');
+               
$GLOBALS['phpgw_setup']->oProc->AlterColumn('fm_ecomva','descr',array('type' => 
'varchar','precision' => '25','nullable' => False));
+               
$GLOBALS['phpgw_setup']->oProc->DropColumn('fm_ecomva',$table_def,'description');
+
+               
$GLOBALS['phpgw_setup']->oProc->RenameColumn('fm_ecobilagtype','name','descr');
+               
$GLOBALS['phpgw_setup']->oProc->AlterColumn('fm_ecobilagtype','descr',array('type'
 => 'varchar','precision' => '25','nullable' => False));
+               
$GLOBALS['phpgw_setup']->oProc->DropColumn('fm_ecobilagtype',$table_def,'description');
+               $GLOBALS['phpgw_setup']->oProc->RenameTable('fm_ecobilagtype', 
'fm_ecobilag_category');
+
+               
$GLOBALS['phpgw_setup']->oProc->RenameColumn('fm_ecoart','name','descr');
+               
$GLOBALS['phpgw_setup']->oProc->AlterColumn('fm_ecoart','descr',array('type' => 
'varchar','precision' => '25','nullable' => False));
+               
$GLOBALS['phpgw_setup']->oProc->DropColumn('fm_ecoart',$table_def,'description');
+
+               unset($table_def);
+               if($GLOBALS['phpgw_setup']->oProc->m_odb->transaction_commit())
+               {
+                       $GLOBALS['setup_info']['property']['currentver'] = 
'0.9.17.536';
+                       return $GLOBALS['setup_info']['property']['currentver'];
+               }
+       }
+
+
 




reply via email to

[Prev in Thread] Current Thread [Next in Thread]
Index: setup/default_records.inc.php
===================================================================
RCS file: /sources/phpgroupware/property/setup/default_records.inc.php,v
retrieving revision 1.38
retrieving revision 1.39
diff -u -b -r1.38 -r1.39
--- setup/default_records.inc.php       24 Nov 2006 14:37:05 -0000      1.38
+++ setup/default_records.inc.php       2 Jan 2007 14:43:03 -0000       1.39
@@ -8,7 +8,7 @@
        * @internal Development of this application was funded by 
http://www.bergen.kommune.no/bbb_/ekstern/
        * @package property
        * @subpackage setup
-       * @version $Id: default_records.inc.php,v 1.38 2006/11/24 14:37:05 
sigurdne Exp $
+       * @version $Id: default_records.inc.php,v 1.39 2007/01/02 14:43:03 
sigurdne Exp $
        */
 
 
@@ -293,30 +293,30 @@
 # Dumping data for table fm_ecoart
 #
 
-$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO fm_ecoart (id, name, 
description) VALUES (1, 'faktura', NULL)");
-$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO fm_ecoart (id, name, 
description) VALUES (2, 'kreditnota', NULL)");
+$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO fm_ecoart (id, name) VALUES 
(1, 'faktura')");
+$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO fm_ecoart (id, name) VALUES 
(2, 'kreditnota')");
 
 
 #
 # Dumping data for table fm_ecobilagtype
 #
 
-$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO fm_ecobilagtype (id, name, 
description) VALUES (1, 'Drift, vedlikehold', NULL)");
-$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO fm_ecobilagtype (id, name, 
description) VALUES (2, 'Prosjekt, Kontrakt', NULL)");
-$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO fm_ecobilagtype (id, name, 
description) VALUES (3, 'Prosjekt, Tillegg', NULL)");
-$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO fm_ecobilagtype (id, name, 
description) VALUES (4, 'Prosjekt, LP-stign', NULL)");
-$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO fm_ecobilagtype (id, name, 
description) VALUES (5, 'Adminstrasjon', NULL)");
+$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO fm_ecobilag_category (id, 
descr) VALUES (1, 'Drift, vedlikehold')");
+$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO fm_ecobilag_category (id, 
descr) VALUES (2, 'Prosjekt, Kontrakt')");
+$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO fm_ecobilag_category (id, 
descr) VALUES (3, 'Prosjekt, Tillegg')");
+$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO fm_ecobilag_category (id, 
descr) VALUES (4, 'Prosjekt, LP-stign')");
+$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO fm_ecobilag_category (id, 
descr) VALUES (5, 'Adminstrasjon')");
 
 #
 # Dumping data for table fm_ecomva
 #
 
-$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO fm_ecomva (id, name, 
description) VALUES (2, 'Mva 2', NULL)");
-$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO fm_ecomva (id, name, 
description) VALUES (1, 'Mva 1', NULL)");
-$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO fm_ecomva (id, name, 
description) VALUES (0, 'ingen', NULL)");
-$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO fm_ecomva (id, name, 
description) VALUES (3, 'Mva 3', NULL)");
-$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO fm_ecomva (id, name, 
description) VALUES (4, 'Mva 4', NULL)");
-$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO fm_ecomva (id, name, 
description) VALUES (5, 'Mva 5', 'Renhold')");
+$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO fm_ecomva (id, descr) 
VALUES (2, 'Mva 2'");
+$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO fm_ecomva (id, descr) 
VALUES (1, 'Mva 1')");
+$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO fm_ecomva (id, descr) 
VALUES (0, 'ingen')");
+$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO fm_ecomva (id, descr) 
VALUES (3, 'Mva 3')");
+$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO fm_ecomva (id, descr) 
VALUES (4, 'Mva 4')");
+$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO fm_ecomva (id, descr) 
VALUES (5, 'Mva 5')");
 
 #
@@ -293,30 +293,30 @@
 
 #
-# Dumping data for table fm_ecobilagtype
+# Dumping data for table fm_ecobilag_category
 #
 
 # Dumping data for table fm_location1_category
